@@ -1,27 +1,32 @@
 # coding=utf-8
-"""
-Create all standard extensions.
-
-"""
+"""Create all standard extensions."""
 
 # Note: Because of issues with circular dependencies, Abilian-specific
 # extensions are created later.
 
 from __future__ import absolute_import, print_function, division
 
-from abilian.core.logging import patch_logger
-from sqlalchemy.engine import Engine
-
-from flask import current_app
-from . import upstream_info
-from .login import login_manager
 import flask_mail
 import sqlalchemy as sa
+import sqlalchemy.orm
+import sqlalchemy.event
+from flask import current_app
+from sqlalchemy.engine import Engine
+
+from abilian.core.logging import patch_logger
+
+from . import upstream_info
+from .login import login_manager
 from ..sqlalchemy import SQLAlchemy
 from .csrf import wtf_csrf as csrf, abilian_csrf
 
 __all__ = [
-    'get_extension', 'db', 'mail', 'login_manager', 'csrf', 'upstream_info'
+    'get_extension',
+    'db',
+    'mail',
+    'login_manager',
+    'csrf',
+    'upstream_info',
 ]
 
 
@@ -70,12 +75,12 @@ def _filter_metadata_for_connection(target, connection, **kw):
                 table.indexes.remove(idx)
 
 
-# csrf
-
-
+#
+# CSRF
+#
 def get_extension(name):
-    """Get the named extension from the current app, returning None if not found.
-    """
+    """Get the named extension from the current app, returning None if not
+    found."""
     return current_app.extensions.get(name)
 
 
@@ -84,16 +89,18 @@ def _install_get_display_value(cls):
     _MARK = object()
 
     def display_value(self, field_name, value=_MARK):
-        """ Return display value for fields having 'choices' mapping (stored value
+        """Return display value for fields having 'choices' mapping (stored
+        value.
+
         -> human readable value). For other fields it will simply return field
         value.
 
         `display_value` should be used instead of directly getting field value.
 
-        If `value` is provided it is "tranlated" to a human-readable value. This is
-        useful for obtaining a human readable label from a raw value
+        If `value` is provided, it is "translated" to a human-readable value. This is
+        useful for obtaining a human readable label from a raw value.
         """
-        val = getattr(self, field_name) if value is _MARK else value
+        val = getattr(self, field_name, "ERROR") if value is _MARK else value
 
         mapper = sa.orm.object_mapper(self)
         try:
