@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -16,8 +15,8 @@ wtf_csrf = CsrfProtect()
 
 
 class AbilianCsrf(object):
-    """Csrf error handler, that allows supporting views to gracefully report error
-    instead of a plain 400 error.
+    """CSRF error handler, that allows supporting views to gracefully report
+    error instead of a plain 400 error.
 
     views supporting this must
     """
@@ -25,15 +24,17 @@ class AbilianCsrf(object):
     #: displayed to user. It can be changed if you have a better one for your
     #: users.
     csrf_failed_message = _l(
-        u'Security informations are missing or expired. '
-        u'This may happen if you have opened the form for a long time. <br /><br />'
-        u'Please try to resubmit the form.')
+        'Security informations are missing or expired. '
+        'This may happen if you have opened the form for a long time. <br /><br />'
+        'Please try to resubmit the form.',
+    )
 
     def init_app(self, app):
         if 'csrf' not in app.extensions:
             raise RuntimeError(
                 'Please install flask_wtf.csrf.CsrfProtect() as "csrf" in extensions'
-                ' before AbilianCsrf()')
+                ' before AbilianCsrf()',
+            )
         app.extensions['csrf'].error_handler(self.csrf_error_handler)
         app.extensions['csrf-handler'] = self
         request_started.connect(self.request_started, sender=app)
@@ -62,7 +63,10 @@ class AbilianCsrf(object):
             return None
 
         if (hasattr(view, 'view_class') and getattr(
-                view.view_class, 'csrf_support_graceful_failure', False)):
+                view.view_class,
+                'csrf_support_graceful_failure',
+                False,
+        )):
             return None
 
         raise BadRequest(failed)
