@@ -1,12 +1,14 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 import abc
 
 import sqlalchemy as sa
+import sqlalchemy.event
+import sqlalchemy.ext.declarative
+from six import add_metaclass
 from sqlalchemy import Column, ForeignKey, Integer, UnicodeText
 from sqlalchemy.orm import backref, relationship
 
@@ -18,8 +20,9 @@ from .blob import Blob
 ATTRIBUTE = '__attachments__'
 
 
+@add_metaclass(abc.ABCMeta)
 class SupportAttachment(object):
-    __metaclass__ = abc.ABCMeta
+    pass
 
 
 def register(cls):
@@ -35,7 +38,8 @@ def register(cls):
     """
     if not issubclass(cls, Entity):
         raise ValueError(
-            'Class must be a subclass of abilian.core.entities.Entity')
+            'Class must be a subclass of abilian.core.entities.Entity',
+        )
 
     SupportAttachment.register(cls)
     return cls
@@ -58,8 +62,7 @@ def is_support_attachments(obj):
 
 
 def for_entity(obj, check_support_attachments=False):
-    """Return attachments on an entity.
-    """
+    """Return attachments on an entity."""
     if check_support_attachments and not is_support_attachments(obj):
         return []
 
@@ -67,8 +70,7 @@ def for_entity(obj, check_support_attachments=False):
 
 
 class Attachment(Entity):
-    """An Attachment owned by an :class:`Entity`.
-    """
+    """An Attachment owned by an :class:`Entity`."""
     __auditable_entity__ = ('entity', 'attachment', ('id', 'name'))
 
     @sa.ext.declarative.declared_attr
@@ -93,7 +95,9 @@ class Attachment(Entity):
             ATTRIBUTE,
             lazy='select',
             order_by='Attachment.created_at',
-            cascade="all, delete-orphan",))
+            cascade="all, delete-orphan",
+        ),
+    )
 
     blob_id = Column(Integer, sa.ForeignKey(Blob.id), nullable=False)
     #: file. Stored in a :class:`Blob`
@@ -103,7 +107,8 @@ class Attachment(Entity):
         UnicodeText(),
         nullable=False,
         default='',
-        server_default='',)
+        server_default='',
+    )
 
     def __repr__(self):
         class_ = self.__class__
