@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -8,7 +7,8 @@ import abc
 from functools import total_ordering
 
 import sqlalchemy as sa
-from six import python_2_unicode_compatible, text_type
+import sqlalchemy.orm
+from six import add_metaclass, python_2_unicode_compatible, text_type
 
 from abilian.core.entities import Entity
 
@@ -18,8 +18,9 @@ from .base import IdMixin, Model
 TAGS_ATTR = '__tags__'
 
 
+@add_metaclass(abc.ABCMeta)
 class SupportTagging(object):
-    __metaclass__ = abc.ABCMeta
+    pass
 
 
 def register(cls):
@@ -35,7 +36,8 @@ def register(cls):
     """
     if not issubclass(cls, Entity):
         raise ValueError(
-            'Class must be a subclass of abilian.core.entities.Entity')
+            'Class must be a subclass of abilian.core.entities.Entity',
+        )
 
     SupportTagging.register(cls)
     return cls
@@ -61,21 +63,27 @@ entity_tag_tbl = sa.Table(
     'entity_tags',
     Model.metadata,
     sa.Column(
-        'tag_id', sa.Integer, sa.ForeignKey(
-            'tag.id', ondelete='CASCADE')),
+        'tag_id',
+        sa.Integer,
+        sa.ForeignKey('tag.id', ondelete='CASCADE'),
+    ),
     sa.Column(
-        'entity_id', sa.Integer, sa.ForeignKey(
-            Entity.id, ondelete='CASCADE')),
-    sa.UniqueConstraint('tag_id', 'entity_id'),)
+        'entity_id',
+        sa.Integer,
+        sa.ForeignKey(Entity.id, ondelete='CASCADE'),
+    ),
+    sa.UniqueConstraint('tag_id', 'entity_id'),
+)
 
 
 @total_ordering
 @python_2_unicode_compatible
 class Tag(IdMixin, Model):
-    """Tags are text labels that can be attached to :class:`entities <.Entity>`.
+    """Tags are text labels that can be attached to :class:`entities
+    <.Entity>`.
 
-    They are namespaced, so that independent group of tags can be defined in the
-    application. The default namespace is `"default"`.
+    They are namespaced, so that independent group of tags can be
+    defined in the application. The default namespace is `"default"`.
     """
     __tablename__ = 'tag'
 
@@ -84,7 +92,8 @@ class Tag(IdMixin, Model):
         sa.UnicodeText(),
         nullable=False,
         default='default',
-        server_default='default')
+        server_default='default',
+    )
 
     #: Label visible to the user
     label = sa.Column(sa.UnicodeText(), nullable=False)
@@ -94,18 +103,22 @@ class Tag(IdMixin, Model):
         Entity,
         collection_class=set,
         secondary=entity_tag_tbl,
-        backref=sa.orm.backref(
-            TAGS_ATTR, collection_class=set),)
+        backref=sa.orm.backref(TAGS_ATTR, collection_class=set),
+    )
 
-    __mapper_args__ = {'order_by': label,}
+    __mapper_args__ = {
+        'order_by': label,
+    }
 
     __table_args__ = (
         sa.UniqueConstraint(ns, label),
         # namespace is not empty and is not surrounded by space characters
-        sa.CheckConstraint(sa.sql.and_(sa.sql.func.trim(ns) == ns, ns != u''),),
+        sa.CheckConstraint(sa.sql.and_(sa.sql.func.trim(ns) == ns, ns != ''),),
         # label is not empty and is not surrounded by space characters
         sa.CheckConstraint(
-            sa.sql.and_(sa.sql.func.trim(label) == label, label != u''),),)
+            sa.sql.and_(sa.sql.func.trim(label) == label, label != ''),
+        ),
+    )
 
     def __str__(self):
         return self.label
@@ -119,4 +132,5 @@ class Tag(IdMixin, Model):
             mod=cls.__module__,
             cls=cls.__name__,
             t=self,
-            addr=id(self),)
+            addr=id(self),
+        )
