@@ -1,12 +1,11 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
 from datetime import datetime, timedelta
 
-from _pytest.python import raises
+from pytest import raises
 
 from abilian.core.entities import Entity
 from abilian.testing import BaseTestCase as AbilianTestCase
