@@ -1,5 +1,5 @@
-"""
-All signals used by Abilian Core.
+# coding=utf-8
+"""All signals used by Abilian Core.
 
 Signals are the main tools used for decoupling applications components by
 sending notifications. In short, signals allow certain senders to notify
@@ -31,3 +31,5 @@ activity = signals.signal("activity")
 #: This signal is sent when user object has been loaded. g.user and current_user
 #: are available.
 user_loaded = signals.signal('user_loaded')
+
+auth_failed = signals.signal('auth_failed')
