@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -22,8 +21,10 @@ class ValueSingletonMeta(type):
 
         if value not in cls.__instances__:
             value_instance = type.__call__(cls, value, *args, **kwargs)
-            cls.__instances__[getattr(value_instance,
-                                      cls.attr)] = value_instance
+            cls.__instances__[getattr(
+                value_instance,
+                cls.attr,
+            )] = value_instance
         return cls.__instances__[value.lower()]
 
 
