@@ -9,15 +9,14 @@ from abilian.core.models.subjects import User
 
 
 def test_non_ascii_password():
-    """Ensure we can store and test non-ascii password without
-    any UnicodeEncodeError.
-    """
+    """Ensure we can store and test non-ascii password without any
+    UnicodeEncodeError."""
     user = User()
 
-    user.set_password(u'Hé')
+    user.set_password('Hé')
 
     if not isinstance(user.password, text_type):
-        # when actually retrieved from database, it should be unicode
+        # when actually retrieved from database, it should be Unicode
         user.password = text_type(user.password)
 
-    assert user.authenticate(u'Hé')
+    assert user.authenticate('Hé')
