@@ -1,9 +1,9 @@
-"""
-Activity Service.
+# coding=utf-8
+"""Activity Service.
 
 See: http://activitystrea.ms/specs/json/1.0/
 See: http://activitystrea.ms/specs/atom/1.0/#activity
-See: http://stackoverflow.com/questions/1443960/how-to-implement-the-activity-stream-in-a-social-network
+See: http://stackoverflow.com/questions/1443960/
 
 TODO: Look wether other attributes from the spec need to be implemented.
 """
@@ -27,11 +27,11 @@ logger = logging.getLogger(__name__)
 
 
 def _default_from(column):
-    """
-    Helper for default and onupdates parameters in a Column definitions.
+    """Helper for default and onupdates parameters in a Column definitions.
 
-    Returns a `context-sensitive default function <http://docs.sqlalchemy.org/en/rel_0_8/core/defaults.html#context-sensitive-default-functions>`_
-    to set value from another column.
+    Returns a `context-sensitive default function
+    <http://docs.sqlalchemy.org/en/rel_0_8/core/defaults.html#context-
+    sensitive-default-functions>`_ to set value from another column.
     """
 
     def _default_value(context):
@@ -41,9 +41,7 @@ def _default_from(column):
 
 
 class ActivityEntry(db.Model):
-    """
-    Main table for all activities.
-    """
+    """Main table for all activities."""
 
     id = Column(Integer, primary_key=True)
     happened_at = Column(DateTime, default=datetime.utcnow)
@@ -64,9 +62,12 @@ class ActivityEntry(db.Model):
     target = relationship(Entity, foreign_keys=_fk_target_id)
 
     def __repr__(self):
-        return ('<{}.ActivityEntry id={} actor={} verb={} object={} '
-                'target={}>'.format(self.__class__.__module__, self.id,
-                                    repr(text_type(self.actor)),
-                                    repr(self.verb),
-                                    repr(text_type(self.object)),
-                                    repr(text_type(self.target))))
+        tpl = '<{}.ActivityEntry id={} actor={} verb={} object={} target={}>'
+        return tpl.format(
+            self.__class__.__module__,
+            self.id,
+            repr(text_type(self.actor)),
+            repr(self.verb),
+            repr(text_type(self.object)),
+            repr(text_type(self.target)),
+        )
