@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-Login-related views (login / logout / password reminder / ...).
+"""Login-related views (login / logout / password reminder / ...).
 
 Notes:
 - Uses code copy/pasted (and modified) from Flask-Security
@@ -11,6 +10,7 @@ from __future__ import absolute_import, division, print_function, \
 import random
 import string
 from datetime import datetime
+from typing import Any
 
 from flask import current_app, flash, redirect, render_template, request, \
     url_for
@@ -19,7 +19,6 @@ from flask.json import jsonify
 from flask_login import login_user, logout_user, user_logged_in, \
     user_logged_out
 from flask_mail import Message
-from flask_security.utils import md5
 from itsdangerous import BadSignature, SignatureExpired, URLSafeTimedSerializer
 from six.moves.urllib.parse import urljoin, urlparse
 from sqlalchemy import sql
@@ -27,6 +26,8 @@ from sqlalchemy.orm.exc import NoResultFound
 
 from abilian.core.extensions import csrf, db
 from abilian.core.models.subjects import User
+from abilian.core.signals import auth_failed
+from abilian.core.util import md5
 from abilian.i18n import _, render_template_i18n
 from abilian.services.security import Anonymous
 from abilian.web.blueprints import Blueprint
@@ -40,7 +41,8 @@ login = Blueprint(
     __name__,
     url_prefix="/user",
     allowed_roles=Anonymous,
-    template_folder='templates')
+    template_folder='templates',
+)
 route = login.route
 
 
@@ -49,8 +51,7 @@ route = login.route
 #
 @route("/login")
 def login_form():
-    """Display the login form.
-    """
+    """Display the login form."""
     next_url = get_redirect_target()
     return render_template("login/login.html", next_url=next_url)
 
@@ -58,27 +59,33 @@ def login_form():
 def do_login(form):
     email = form.get('email', "").lower()
     password = form.get('password')
-    next_url = form.get('next', u'')
+    next_url = form.get('next', '')
     res = dict(username=email, email=email, next_url=next_url)
 
     if not email or not password:
-        res['error'] = _(u"You must provide your email and password.")
+        res['error'] = _("You must provide your email and password.")
         res['code'] = 401
         return res
 
     try:
         user = User.query \
-            .filter(sql.func.lower(User.email) == email,
-                    User.can_login == True) \
+            .filter(
+                sql.func.lower(User.email) == email,
+                User.can_login == True,
+            ) \
             .one()
     except NoResultFound:
-        res['error'] = _(u"Sorry, we couldn't find an account for "
-                         u"email '{email}'.").format(email=email)
+        auth_failed.send(current_app._get_current_object(), email=email)
+        res['error'] = _(
+            "Sorry, we couldn't find an account for "
+            "email '{email}'.",
+        ).format(email=email)
         res['code'] = 401
         return res
 
     if user and not user.authenticate(password):
-        res['error'] = _(u"Sorry, wrong password.")
+        auth_failed.send(current_app._get_current_object(), email=email)
+        res['error'] = _("Sorry, wrong password.")
         res['code'] = 401
         return res
 
@@ -130,7 +137,7 @@ def logout():
 @route("/api/logout", methods=['POST'])
 def logout_json():
     logout_user()
-    return u'Logged out, ok.', 200
+    return '{}', 200, {'content-type': 'application/json'}
 
 
 #
@@ -146,8 +153,7 @@ def forgotten_pw_form():
 @route("/forgotten_pw", methods=['POST'])
 @csrf.exempt
 def forgotten_pw(new_user=False):
-    """Reset password for users who have already activated their accounts.
-    """
+    """Reset password for users who have already activated their accounts."""
     email = request.form.get('email', "").lower()
 
     action = request.form.get('action')
@@ -155,17 +161,23 @@ def forgotten_pw(new_user=False):
         return redirect(url_for("login.login_form"))
 
     if not email:
-        flash(_(u"You must provide your email address."), 'error')
+        flash(_("You must provide your email address."), 'error')
         return render_template("login/forgotten_password.html")
 
     try:
         user = User.query \
-            .filter(sql.func.lower(User.email) == email,
-                    User.can_login == True) \
+            .filter(
+                sql.func.lower(User.email) == email,
+                User.can_login == True,
+            ) \
             .one()
     except NoResultFound:
-        flash(_(u"Sorry, we couldn't find an account for "
-                "email '{email}'.").format(email=email), 'error')
+        flash(
+            _(
+                "Sorry, we couldn't find an account for "
+                "email '{email}'.",
+            ).format(email=email), 'error',
+        )
         return render_template("login/forgotten_password.html"), 401
 
     if user.can_login and not user.password:
@@ -173,8 +185,10 @@ def forgotten_pw(new_user=False):
         db.session.commit()
 
     send_reset_password_instructions(user)
-    flash(_("Password reset instructions have been sent to your email address."),
-          'info')
+    flash(
+        _("Password reset instructions have been sent to your email address."),
+        'info',
+    )
 
     return redirect(url_for("login.login_form"))
 
@@ -183,9 +197,9 @@ def forgotten_pw(new_user=False):
 def reset_password(token):
     expired, invalid, user = reset_password_token_status(token)
     if invalid:
-        flash(_(u"Invalid reset password token."), "error")
+        flash(_("Invalid reset password token."), "error")
     elif expired:
-        flash(_(u"Password reset expired"), "error")
+        flash(_("Password reset expired"), "error")
     if invalid or expired:
         return redirect(url_for('login.forgotten_pw'))
 
@@ -202,53 +216,59 @@ def reset_password_post(token):
     expired, invalid, user = reset_password_token_status(token)
 
     if invalid or not user:
-        flash(_(u"Invalid reset password token."), "error")
+        flash(_("Invalid reset password token."), "error")
     elif expired:
-        flash(_(u"Password reset expired"), "error")
+        flash(_("Password reset expired"), "error")
     if invalid or expired or not user:
         return redirect(url_for('login.forgotten_pw'))
 
     password = request.form.get('password')
 
     if not password:
-        flash(_(u"You must provide a password."), "error")
+        flash(_("You must provide a password."), "error")
         return redirect(url_for("login.reset_password_post", token=token))
 
     # TODO: check entropy
     if len(password) < 7:
-        flash(_(u"Your new password must be at least 8 characters long"), "error")
+        flash(_("Your new password must be at least 8 characters long"), "error")
         return redirect(url_for("login.reset_password_post", token=token))
 
     if password.lower() == password:
-        flash(_(u"Your new password must contain upper case and lower case "
-                "letters"), "error")
+        flash(
+            _(
+                "Your new password must contain upper case and lower case "
+                "letters",
+            ), "error",
+        )
         return redirect(url_for("login.reset_password_post", token=token))
 
     if not len([x for x in password if x.isdigit()]) > 0:
-        flash(_(u"Your new password must contain at least one digit"), "error")
+        flash(_("Your new password must contain at least one digit"), "error")
         return redirect(url_for("login.reset_password_post", token=token))
 
     user.set_password(password)
     db.session.commit()
 
-    flash(_(u"Your password has been changed. "
-            u"You can now login with your new password"),
-          "success")
+    flash(
+        _(
+            "Your password has been changed. "
+            "You can now login with your new password",
+        ),
+        "success",
+    )
 
     return redirect(url_for("login.login_form", next_url=request.url_root))
 
 
 def random_password():
     pw = []
-    for i in range(0, 10):
+    for _i in range(0, 10):
         pw.append(random.choice(string.letters + string.digits))
     return pw
 
 
 def get_serializer(name):
-    """
-    :type name: str
-    """
+    # type: (str) -> Any
     config = current_app.config
     secret_key = config.get('SECRET_KEY')
     salt = config.get('SECURITY_{}_SALT'.format(name.upper()))
@@ -256,33 +276,40 @@ def get_serializer(name):
 
 
 def send_reset_password_instructions(user):
+    # type: (User) -> None
     """Send the reset password instructions email for the specified user.
 
     :param user: The user to send the instructions to
-    :type user: User
     """
     token = generate_reset_password_token(user)
     url = url_for('login.reset_password', token=token)
     reset_link = request.url_root[:-1] + url
 
-    subject = _(u"Password reset instruction for {site_name}"
-                ).format(site_name=current_app.config.get('SITE_NAME'))
+    subject = _(
+        "Password reset instruction for {site_name}",
+    ).format(site_name=current_app.config.get('SITE_NAME'))
     mail_template = 'password_reset_instructions'
     send_mail(
-        subject, user.email, mail_template, user=user, reset_link=reset_link)
+        subject,
+        user.email,
+        mail_template,
+        user=user,
+        reset_link=reset_link,
+    )
 
 
 def generate_reset_password_token(user):
+    # type: (User) -> Any
     """Generate a unique reset password token for the specified user.
 
     :param user: The user to work with
-    :type user: User
     """
     data = [str(user.id), md5(user.password)]
     return get_serializer("reset").dumps(data)
 
 
 def reset_password_token_status(token):
+    # type: (str) -> Any
     """Return the expired status, invalid status, and user of a password reset
     token.
 
@@ -291,14 +318,13 @@ def reset_password_token_status(token):
         expired, invalid, user = reset_password_token_status('...')
 
     :param token: The password reset token
-    :type token: str
     """
     return get_token_status(token, 'reset', 'RESET_PASSWORD')
 
 
 def get_token_status(token, serializer_name, max_age=None):
     serializer = get_serializer(serializer_name)
-    #max_age = get_max_age(max_age)
+    # max_age = get_max_age(max_age)
     user, data = None, None
     expired, invalid = False, False
 
@@ -330,9 +356,9 @@ def send_mail(subject, recipient, template, **context):
     sender = config['MAIL_SENDER']
     msg = Message(subject, sender=sender, recipients=[recipient])
 
-    ctx = ('login/email', template)
-    msg.body = render_template_i18n('%s/%s.txt' % ctx, **context)
-    #msg.html = render_template('%s/%s.html' % ctx, **context)
+    template_name = 'login/email/{}.txt'.format(template)
+    msg.body = render_template_i18n(template_name, **context)
+    # msg.html = render_template('%s/%s.html' % ctx, **context)
 
     mail = current_app.extensions.get('mail')
     current_app.logger.debug("Sending mail...")
