@@ -1,9 +1,8 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
-from .service import service
 from .schema import indexable_role
+from .service import service
 
 __all__ = ['service', 'indexable_role']
