@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -17,8 +16,9 @@ from abilian.services.security.models import Anonymous, Role
 
 #: A Whoosh analyzer that splits on word boundaries and folds accents and case.
 accent_folder = (
-    RegexTokenizer(r'\w+')  # defaults doesn't split on '.'
-    | LowercaseFilter() | CharsetFilter(accent_map))
+    RegexTokenizer(r'\w+') |  # defaults doesn't split on '.'
+    LowercaseFilter() | CharsetFilter(accent_map)
+)
 
 #: Analyzer for edge-ngrams, from 2 to 6 characters long
 edge_ngram = accent_folder | NgramFilter(minsize=2, maxsize=6, at='start')
@@ -29,8 +29,7 @@ def EdgeNgramField():
 
 
 class _DefaultSearchSchema(SchemaClass):
-    """General search schema.
-    """
+    """General search schema."""
     object_key = ID(stored=True, unique=True)
     id = NUMERIC(numtype=int, bits=64, signed=False, stored=True, unique=False)
     object_type = ID(stored=True, unique=False)
@@ -47,7 +46,11 @@ class _DefaultSearchSchema(SchemaClass):
 
     # hierarchical index of ids path ('/' is the separator)
     parent_ids = FieldType(
-        format=Existence(), analyzer=PathTokenizer(), stored=True, unique=False)
+        format=Existence(),
+        analyzer=PathTokenizer(),
+        stored=True,
+        unique=False,
+    )
 
     name = TEXT(stored=True, analyzer=accent_folder)
     slug = ID(stored=True)
@@ -57,8 +60,7 @@ class _DefaultSearchSchema(SchemaClass):
 
 _default_dyn_fields = {
     '*_prefix': EdgeNgramField(),
-    '*_at': DATETIME(
-        stored=True, sortable=True),
+    '*_at': DATETIME(stored=True, sortable=True),
 }
 
 
@@ -78,16 +80,16 @@ def indexable_role(principal):
     """
     principal = noproxy(principal)
 
-    if (hasattr(principal, 'is_anonymous') and principal.is_anonymous):
+    if hasattr(principal, 'is_anonymous') and principal.is_anonymous:
         # transform anonymous user to anonymous role
         principal = Anonymous
 
     if isinstance(principal, Role):
-        return u'role:{}'.format(principal.name)
+        return 'role:{}'.format(principal.name)
     elif isinstance(principal, User):
-        fmt = u'user:{:d}'
+        fmt = 'user:{:d}'
     elif isinstance(principal, Group):
-        fmt = u'group:{:d}'
+        fmt = 'group:{:d}'
     else:
         raise ValueError(repr(principal))
 
