@@ -1,6 +1,5 @@
-"""
-Models for user preferences.
-"""
+# coding=utf-8
+"""Models for user preferences."""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -13,8 +12,7 @@ from abilian.core.sqlalchemy import JSON
 
 
 class UserPreference(db.Model):
-    """An atom of user preference.
-    """
+    """An atom of user preference."""
     __tablename__ = 'user_preference'
     __table_args__ = (UniqueConstraint('user_id', 'key'),)
 
@@ -24,8 +22,8 @@ class UserPreference(db.Model):
     #: The user who set this preference.
     user = relation(
         User,
-        backref=backref(
-            'preferences', cascade="all, delete, delete-orphan"))
+        backref=backref('preferences', cascade="all, delete, delete-orphan"),
+    )
     user_id = Column(ForeignKey(User.id))
 
     #: The key
