@@ -1,13 +1,12 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
-from flask import current_app
 from flask_login import current_user
 
 from abilian.core.models.subjects import User
+from abilian.services import get_service
 from abilian.testing import BaseTestCase
 
 from .models import UserPreference
@@ -29,8 +28,8 @@ class AdminPanel(PreferencePanel):
     id = label = 'admin'
 
     def is_accessible(self):
-        security_service = current_app.services['security']
-        return security_service.has_role(current_user, "admin")
+        security = get_service('security')
+        return security.has_role(current_user, "admin")
 
     def get(self):
         return 'Admin'
@@ -57,19 +56,19 @@ class PreferencesTestCase(BaseTestCase):
         preference_service = PreferenceService()
 
         preferences = preference_service.get_preferences(user)
-        self.assertEqual(preferences, {})
+        assert preferences == {}
 
         preference_service.set_preferences(user, digest='daily')
         self.session.flush()
 
         preferences = preference_service.get_preferences(user)
-        self.assertEqual(preferences, {'digest': 'daily'})
+        assert preferences == {'digest': 'daily'}
 
         preference_service.clear_preferences(user)
         self.session.flush()
 
         preferences = preference_service.get_preferences(user)
-        self.assertEqual(preferences, {})
+        assert preferences == {}
         assert UserPreference.query.all() == []
 
     def test_preferences_with_various_types(self):
@@ -79,12 +78,12 @@ class PreferencesTestCase(BaseTestCase):
         preference_service.set_preferences(user, some_int=1)
         self.session.flush()
         preferences = preference_service.get_preferences(user)
-        self.assertEqual(preferences, {'some_int': 1})
+        assert preferences == {'some_int': 1}
 
         preference_service.set_preferences(user, some_bool=True)
         self.session.flush()
         preferences = preference_service.get_preferences(user)
-        self.assertEqual(preferences, {'some_int': 1, 'some_bool': True})
+        assert preferences == {'some_int': 1, 'some_bool': True}
 
     def test_visible_panels(self):
         user = User(email="test@example.com")
@@ -98,9 +97,10 @@ class PreferencesTestCase(BaseTestCase):
                 break
 
         with self.login(user):
-            assert [p['endpoint']
-                    for p in ctx['menu']] == ['preferences.visible']
+            expected = ['preferences.visible']
+            assert [p['endpoint'] for p in ctx['menu']] == expected
+
             security.grant_role(user, 'admin')
             ctx = cp()
-            assert [p['endpoint'] for p in ctx['menu']
-                   ] == ['preferences.visible', 'preferences.admin']
+            expected = ['preferences.visible', 'preferences.admin']
+            assert [p['endpoint'] for p in ctx['menu']] == expected
