@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -9,11 +8,11 @@ import weakref
 from pathlib import Path
 from uuid import UUID, uuid1
 
-import six
 import sqlalchemy as sa
+import sqlalchemy.event
 from flask import _app_ctx_stack, current_app
 from flask.globals import _lookup_app_object
-from six import string_types, text_type
+from six import text_type
 from sqlalchemy.orm.session import Session
 
 from abilian.services import Service, ServiceState
@@ -32,9 +31,7 @@ class RepositoryServiceState(ServiceState):
 
 
 class RepositoryService(Service):
-    """
-    Service for storage of binary objects referenced in database
-    """
+    """Service for storage of binary objects referenced in database."""
     name = 'repository'
     AppStateClass = RepositoryServiceState
 
@@ -71,9 +68,8 @@ class RepositoryService(Service):
         return dest
 
     def get(self, uuid, default=None):
-        """
-        Return absolute :class:`Path` object for given uuid, if this uuid exists in
-        repository, or `default` if it doesn't.
+        """Return absolute :class:`Path` object for given uuid, if this uuid
+        exists in repository, or `default` if it doesn't.
 
         :param:uuid: :class:`UUID` instance
         """
@@ -83,7 +79,7 @@ class RepositoryService(Service):
         return path
 
     def set(self, uuid, content, encoding='utf-8'):
-        """Store binary content with uuid as key
+        """Store binary content with uuid as key.
 
         :param:uuid: :class:`UUID` instance
         :param:content: string, bytes, or any object with a `read()` method
@@ -196,7 +192,8 @@ class SessionRepositoryState(ServiceState):
         tr = self.get_transaction(session)
         if tr is not None:
             if not tr.cleared:
-                # root and nested transactions emit "commit", but subtransactions don't
+                # root and nested transactions emit "commit", but
+                # subtransactions don't
                 tr.commit(session)
             self.set_transaction(session, tr._parent)
 
@@ -239,8 +236,7 @@ class SessionRepositoryState(ServiceState):
 
 
 class SessionRepositoryService(Service):
-    """
-    A repository service that is session aware, i.e content is actually
+    """A repository service that is session aware, i.e content is actually
     written or delete at commit time.
 
     All content is stored using the main :class:`RepositoryService`.
@@ -265,7 +261,10 @@ class SessionRepositoryService(Service):
         if not self.__listening:
             self.__listening = True
             listen = sa.event.listen
-            listen(Session, "after_transaction_create", self.create_transaction)
+            listen(
+                Session,
+                "after_transaction_create",
+                self.create_transaction)
             listen(Session, "after_transaction_end", self.end_transaction)
             listen(Session, "after_begin", self.begin)
             listen(Session, "after_commit", self.commit)
@@ -393,8 +392,7 @@ class RepositoryTransaction(object):
         self._clear()
 
     def commit(self, session=None):
-        """
-        Merge modified objects into parent transaction.
+        """Merge modified objects into parent transaction.
 
         Once commited a transaction object is not usable anymore
 
@@ -440,9 +438,8 @@ class RepositoryTransaction(object):
             content_path.rename(p.path / str(uuid))
 
     def _add_to(self, uuid, dest, other):
-        """
-        Add `item` to `dest` set, ensuring `item` is not present in `other` set.
-        """
+        """Add `item` to `dest` set, ensuring `item` is not present in `other`
+        set."""
         _assert_uuid(uuid)
         try:
             other.remove(uuid)
