@@ -1,3 +1,4 @@
+# coding=utf-8
 """Another try at an activity service.
 
 See: ActivityStreams, OpenSocial
@@ -9,15 +10,12 @@ from __future__ import absolute_import, division, print_function, \
 
 
 class Activity(object):
-    """
-  Persistent object that represents an activity entry.
-  """
+    """Persistent object that represents an activity entry."""
 
 
 class ActivityService(object):
 
     def post(self, activity):
-        """Post an activity to the service.
-    """
+        """Post an activity to the service."""
 
     # Now we need some methods to query the stream
