@@ -2,8 +2,6 @@
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
-import unittest
-
 import pytest
 
 from abilian.core.entities import Entity
@@ -15,7 +13,7 @@ from . import READ, WRITE, Admin, Anonymous, Authenticated, Creator, \
     InheritSecurity, Owner, Permission, PermissionAssignment, Reader, Role, \
     RoleAssignment, SecurityAudit, Writer, security
 
-TEST_EMAIL = u"joe@example.com"
+TEST_EMAIL = "joe@example.com"
 TEST_PASSWORD = "tototiti"
 
 skip = pytest.mark.skip
@@ -26,31 +24,31 @@ def init_user():
         first_name="Joe",
         last_name="User",
         email=TEST_EMAIL,
-        password=TEST_PASSWORD)
+        password=TEST_PASSWORD,
+    )
     db.session.add(user)
     db.session.flush()
 
 
-class RoleTestCase(unittest.TestCase):
+def test_singleton():
+    admin = Role('admin')
+    other_admin = Role('admin')
+    assert admin is other_admin
+    assert id(admin) == id(other_admin)
 
-    def test_singleton(self):
-        admin = Role('admin')
-        other_admin = Role('admin')
-        self.assertIs(admin, other_admin)
-        self.assertEqual(id(admin), id(other_admin))
 
-    def test_equality(self):
-        admin = Role('admin')
-        self.assertEqual(admin, 'admin')
-        self.assertEqual(admin, u'admin')
+def test_equality():
+    admin = Role('admin')
+    assert admin == 'admin'
 
-    def test_ordering(self):
-        roles = [Authenticated, Admin, Anonymous]
-        roles.sort()
-        assert roles == [Admin, Anonymous, Authenticated]
 
-    def test_enumerate_assignables(self):
-        assert Role.assignable_roles() == [Admin]
+def test_ordering():
+    roles = sorted([Authenticated, Admin, Anonymous])
+    assert roles == [Admin, Anonymous, Authenticated]
+
+
+def test_enumerate_assignables():
+    assert Role.assignable_roles() == [Admin]
 
 
 class IntegrationTestCase(BaseTestCase):
@@ -95,8 +93,7 @@ class SecurityTestCase(IntegrationTestCase):
         assert security.has_role(user, Authenticated)
 
     def test_root_user(self):
-        """Root user always has any role, any permission.
-        """
+        """Root user always has any role, any permission."""
         root = User.query.get(0)
         assert security.has_role(root, Admin)
         assert security.has_role(root, Anonymous)
@@ -274,17 +271,17 @@ class SecurityTestCase(IntegrationTestCase):
         self.session.add(folder)
         self.session.flush()
 
-        self.assertEqual(SecurityAudit.query.count(), 0)
+        assert SecurityAudit.query.count() == 0
 
         security.set_inherit_security(folder, False)
         self.session.flush()
-        self.assertFalse(folder.inherit_security)
-        self.assertEqual(SecurityAudit.query.count(), 1)
+        assert not folder.inherit_security
+        assert SecurityAudit.query.count() == 1
 
         security.set_inherit_security(folder, True)
         self.session.flush()
-        self.assertTrue(folder.inherit_security)
-        self.assertEqual(SecurityAudit.query.count(), 2)
+        assert folder.inherit_security
+        assert SecurityAudit.query.count() == 2
 
     def test_add_list_delete_permissions(self):
         obj = DummyModel()
@@ -315,7 +312,11 @@ class SecurityTestCase(IntegrationTestCase):
 
         # set/get/delete global permission
         security.add_permission(READ, Writer)
-        assert security.get_permissions_assignments() == {READ: {Writer,},}
+        assert security.get_permissions_assignments() == {
+            READ: {
+                Writer,
+            },
+        }
 
     def test_has_permission_on_objects(self):
         has_permission = security.has_permission
@@ -342,7 +343,10 @@ class SecurityTestCase(IntegrationTestCase):
         assert not has_permission(user, WRITE, obj=obj)
 
         pa = PermissionAssignment(
-            role=Authenticated, permission=READ, object=obj)
+            role=Authenticated,
+            permission=READ,
+            object=obj,
+        )
         self.session.add(pa)
         self.session.flush()
         assert has_permission(user, READ, obj=obj)
@@ -354,7 +358,7 @@ class SecurityTestCase(IntegrationTestCase):
 
         # Owner / Creator
         for role in (Owner, Creator):
-            pa = PermissionAssignment(role=Owner, permission=READ, object=obj)
+            pa = PermissionAssignment(role=role, permission=READ, object=obj)
             self.session.add(pa)
             self.session.flush()
             assert has_permission(user, READ, obj=obj)
@@ -412,10 +416,16 @@ class SecurityTestCase(IntegrationTestCase):
 
         assigments = [
             PermissionAssignment(
-                role=Reader, permission=READ, object=obj_reader),
+                role=Reader,
+                permission=READ,
+                object=obj_reader,
+            ),
             #
             PermissionAssignment(
-                role=Writer, permission=WRITE, object=obj_writer)
+                role=Writer,
+                permission=WRITE,
+                object=obj_writer,
+            ),
         ]
         self.session.add_all(assigments)
         self.session.flush()
@@ -439,7 +449,10 @@ class SecurityTestCase(IntegrationTestCase):
 
         # Permission granted to anonymous: objects returned
         pa = PermissionAssignment(
-            role=Anonymous, permission=WRITE, object=obj_reader)
+            role=Anonymous,
+            permission=WRITE,
+            object=obj_reader,
+        )
         self.session.add(pa)
 
         assert base_query.filter(get_filter(READ, user=user)).all() \
@@ -457,10 +470,12 @@ class SecurityTestCase(IntegrationTestCase):
         security.grant_role(user, Writer)
         self.session.flush()
 
-        assert base_query.filter(get_filter(
-            READ, user=user)).all() == [obj_reader]
-        assert base_query.filter(get_filter(
-            WRITE, user=user)).all() == [obj_writer]
+        assert base_query.filter(
+            get_filter(READ, user=user),
+        ).all() == [obj_reader]
+        assert base_query.filter(
+            get_filter(WRITE, user=user),
+        ).all() == [obj_writer]
 
         # admin role has all permissions
         # 1: local role
@@ -471,9 +486,9 @@ class SecurityTestCase(IntegrationTestCase):
         self.session.flush()
 
         assert set(base_query.filter(get_filter(READ, user=user)).all()) == \
-          {obj_reader, obj_none}
+            {obj_reader, obj_none}
         assert set(base_query.filter(get_filter(WRITE, user=user)).all()) == \
-          {obj_reader, obj_none}
+            {obj_reader, obj_none}
 
         # 2: global role
         security.ungrant_role(user, Admin, object=obj_reader)
@@ -492,10 +507,16 @@ class SecurityTestCase(IntegrationTestCase):
         obj_writer.owner = user
         assigments = [
             PermissionAssignment(
-                role=Creator, permission=READ, object=obj_reader),
+                role=Creator,
+                permission=READ,
+                object=obj_reader,
+            ),
             #
             PermissionAssignment(
-                role=Owner, permission=WRITE, object=obj_writer)
+                role=Owner,
+                permission=WRITE,
+                object=obj_writer,
+            ),
         ]
         self.session.add_all(assigments)
         self.session.flush()
@@ -525,7 +546,9 @@ class PermissionNoSAWarnTestCase(IntegrationTestCase):
         security.add_permission(READ, Owner, None)
         obj = DummyModel()
         # override default permission at instance level
-        obj.__default_permissions__ = frozenset({(READ, frozenset({Owner})),})
+        obj.__default_permissions__ = frozenset({
+            (READ, frozenset({Owner})),
+        })
         # core.entities._setup_default_permissions creates
         self.session.add(obj)
         # permissions
@@ -540,5 +563,6 @@ class PermissionNoSAWarnTestCase(IntegrationTestCase):
         # them just after (as of sqlalchemy 0.8, at least)
 
         # Finally the test! IntegrityError will be raised if we have done something
-        # wrong (`Key (permission, role, object_id)=(..., ..., ...) already exists`)
+        # wrong (`Key (permission, role, object_id)=(..., ..., ...) already
+        # exists`)
         self.session.flush()
