@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -26,7 +25,7 @@ def test_type_set():
 def test_int():
     s = Setting(key='key', type='int')
     s.value = 42
-    assert s._value == '42'
+    assert s._value in ('42', b'42')
 
     s._value = '24'
     assert s.value == 24
@@ -49,19 +48,19 @@ def test_bool():
 
 def test_string():
     s = Setting(key='key', type='string')
-    s.value = u'ascii'
+    s.value = 'ascii'
     assert s._value == b'ascii'
 
-    s.value = u'bel été'
+    s.value = 'bel été'
     assert s._value == b'bel \xc3\xa9t\xc3\xa9'
 
     s._value = b'd\xc3\xa9code'
-    assert s.value == u'décode'
+    assert s.value == 'décode'
 
 
 def test_json():
     s = Setting(key='key', type='json')
-    s.value = [1, 2, u'été', {1: '1', 2: '2'}]
+    s.value = [1, 2, 'été', {1: '1', 2: '2'}]
     assert s._value == '[1, 2, "\\u00e9t\\u00e9", {"1": "1", "2": "2"}]'
 
     s.value = None
@@ -87,7 +86,7 @@ class SettingsServiceTestCase(BaseTestCase):
         assert svc.get('key_1') == 42
 
         # new key with no type: raise error:
-        with self.assertRaises(ValueError):
+        with pytest.raises(ValueError):
             svc.set('key_err', 42)
 
         # key already with type_, this should not raise an error
@@ -97,14 +96,14 @@ class SettingsServiceTestCase(BaseTestCase):
 
         svc.delete('key_1')
         self.db.session.flush()
-        with self.assertRaises(KeyError):
+        with pytest.raises(KeyError):
             svc.get('key_1')
 
         # delete: silent by default
         svc.delete('non_existent')
 
         # delete: non-silent
-        with self.assertRaises(KeyError):
+        with pytest.raises(KeyError):
             svc.delete('non_existent', silent=False)
 
         # tricky use case: ask key delete, set it later, then flush
@@ -123,7 +122,7 @@ class SettingsServiceTestCase(BaseTestCase):
         assert sorted(svc.keys(prefix='key_')) == ['key_1', 'key_2']
 
         # as dict
-        assert svc.as_dict() == {'other': u'azerty', 'key_1': 1, 'key_2': 2}
+        assert svc.as_dict() == {'other': 'azerty', 'key_1': 1, 'key_2': 2}
         assert svc.as_dict(prefix='key_') == {'key_1': 1, 'key_2': 2}
 
     def test_namespace(self):
@@ -149,18 +148,19 @@ class SettingsServiceTestCase(BaseTestCase):
         self.db.session.flush()
         assert sub.get('1') == 1
         assert ns.get('1') == 42
-        assert sorted(svc.keys(
-        )) == ['other', 'test:1', 'test:sub:1', 'test:sub:2']
+        assert sorted(
+            svc.keys(),
+        ) == ['other', 'test:1', 'test:sub:1', 'test:sub:2']
 
         # as dict
         assert sub.as_dict() == {'1': 1, '2': 2}
         assert ns.as_dict(prefix='sub:') == {'sub:1': 1, 'sub:2': 2}
         assert ns.as_dict() == {'1': 42, 'sub:1': 1, 'sub:2': 2}
         assert svc.as_dict() == {
-            'other': u'not in NS',
+            'other': 'not in NS',
             'test:1': 42,
             'test:sub:1': 1,
-            'test:sub:2': 2
+            'test:sub:2': 2,
         }
 
         # deletion
