@@ -1,10 +1,13 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
+import sys
+
 import sqlalchemy as sa
+import sqlalchemy.exc
+from pytest import mark
 
 from abilian.testing import BaseTestCase
 from abilian.web import url_for
@@ -17,29 +20,35 @@ class TestVocabularies(BaseTestCase):
 
     DefaultVoc = Vocabulary('defaultstates', label='States')
 
+    @mark.skipif(sys.version_info >= (3, 0), reason="Doesn't work yet on Py3k")
     def test_vocabulary_creator(self):
         PriorityVoc = Vocabulary('priorities', label='Priorities')
         assert PriorityVoc.__name__ == 'VocabularyPriorities'
         assert PriorityVoc.__tablename__ == 'vocabulary_priorities'
-        assert PriorityVoc.Meta.name == u'priorities'
-        assert PriorityVoc.Meta.label == u'Priorities'
+        assert PriorityVoc.Meta.name == 'priorities'
+        assert PriorityVoc.Meta.label == 'Priorities'
         assert PriorityVoc.Meta.group is None
         assert issubclass(PriorityVoc, BaseVocabulary)
 
         StateVoc = self.DefaultVoc
         DocCatVoc = Vocabulary(
-            'categories', group='documents', label='Categories')
+            'categories',
+            group='documents',
+            label='Categories',
+        )
 
         # test registered vocabularies
         assert vocabularies.vocabularies == {PriorityVoc, StateVoc, DocCatVoc}
         assert (vocabularies.grouped_vocabularies == {
             None: [StateVoc, PriorityVoc],
-            'documents': [DocCatVoc]
+            'documents': [DocCatVoc],
         })
         assert vocabularies.get_vocabulary('priorities') is PriorityVoc
         assert vocabularies.get_vocabulary('priorities', 'nogroup') is None
-        assert vocabularies.get_vocabulary('categories',
-                                           'documents') is DocCatVoc
+        assert vocabularies.get_vocabulary(
+            'categories',
+            'documents',
+        ) is DocCatVoc
 
         self.app.db.create_all()
 
@@ -48,7 +57,8 @@ class TestVocabularies(BaseTestCase):
         URGENT = PriorityVoc(label='Urgent', position=1)
         HIGH = PriorityVoc(label='High', position=2)
         items = (IMMEDIATE, NORMAL, URGENT, HIGH)
-        map(self.session.add, items)
+        for item in items:
+            self.session.add(item)
         self.session.flush()
 
         # test position=4 set automatically; Label stripped
@@ -56,21 +66,31 @@ class TestVocabularies(BaseTestCase):
         self.session.add(low_item)
         self.session.flush()
         assert low_item.position == 4
-        assert low_item.label == u'Low'
+        assert low_item.label == 'Low'
 
         # test strip label on update
-        IMMEDIATE.label = u'  Immediate  '
+        IMMEDIATE.label = '  Immediate  '
         self.session.flush()
-        assert IMMEDIATE.label == u'Immediate'
+        assert IMMEDIATE.label == 'Immediate'
 
         # test default ordering
-        assert ([i.label for i in PriorityVoc.query.active().all()] ==
-                [u'Immediate', u'Urgent', u'High', u'Normal', u'Low'])
+        assert ([i.label for i in PriorityVoc.query.active().all()] == [
+            'Immediate',
+            'Urgent',
+            'High',
+            'Normal',
+            'Low',
+        ])
 
         # no default ordering when using .values(): explicit ordering required
         query = PriorityVoc.query.active().order_by(PriorityVoc.position.asc())
-        assert ([i.label for i in query.values(PriorityVoc.label)] ==
-                [u'Immediate', u'Urgent', u'High', u'Normal', u'Low'])
+        assert ([i.label for i in query.values(PriorityVoc.label)] == [
+            'Immediate',
+            'Urgent',
+            'High',
+            'Normal',
+            'Low',
+        ])
 
         # test db-side constraint for non-empty labels
         try:
@@ -113,8 +133,12 @@ class TestVocabularies(BaseTestCase):
         item = PriorityVoc.query.by_position(URGENT.position)
         assert item is URGENT
         item.active = False
-        assert ([i.label for i in PriorityVoc.query.active().all()] ==
-                [u'Immediate', u'High', u'Normal', u'Low'])
+        assert ([i.label for i in PriorityVoc.query.active().all()] == [
+            'Immediate',
+            'High',
+            'Normal',
+            'Low',
+        ])
         assert PriorityVoc.query.active().by_position(URGENT.position) is None
 
         # test by_label()
@@ -141,35 +165,35 @@ class TestVocabularies(BaseTestCase):
         data.update(base_data)
         r = self.client.post(url, data=data)
         assert r.status_code == 302
-        assert r.headers['Location'] == u'http://localhost/admin/vocabularies'
+        assert r.headers['Location'] == 'http://localhost/admin/vocabularies'
         assert Voc.query.order_by(Voc.position).all() == [second, first, third]
 
         data = {'up': first.id, 'return_to': 'group'}
         data.update(base_data)
         r = self.client.post(url, data=data)
         assert r.status_code == 302
-        assert r.headers[
-            'Location'] == u'http://localhost/admin/vocabularies/_/'
+        assert r.headers['Location'] \
+            == 'http://localhost/admin/vocabularies/_/'
         assert Voc.query.order_by(Voc.position).all() == [first, second, third]
 
         data = {'up': first.id, 'return_to': 'model'}
         data.update(base_data)
         r = self.client.post(url, data=data)
         assert r.status_code == 302
-        assert (r.headers['Location'] ==
-                u'http://localhost/admin/vocabularies/_/defaultstates/')
+        assert r.headers['Location'] \
+            == 'http://localhost/admin/vocabularies/_/defaultstates/'
         assert Voc.query.order_by(Voc.position).all() == [first, second, third]
 
         data = {'down': third.id}
         data.update(base_data)
         r = self.client.post(url, data=data)
         assert r.status_code == 302
-        assert r.headers['Location'] == u'http://localhost/admin/vocabularies'
+        assert r.headers['Location'] == 'http://localhost/admin/vocabularies'
         assert Voc.query.order_by(Voc.position).all() == [first, second, third]
 
         data = {'up': third.id}
         data.update(base_data)
         r = self.client.post(url, data=data)
         assert r.status_code == 302
-        assert r.headers['Location'] == u'http://localhost/admin/vocabularies'
+        assert r.headers['Location'] == 'http://localhost/admin/vocabularies'
         assert Voc.query.order_by(Voc.position).all() == [first, third, second]
