@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -14,7 +13,8 @@ from ..panel import AdminPanel
 
 DATA_FILES = (
     '/usr/share/GeoIP/GeoIP.dat',
-    '/usr/share/GeoIP/GeoIPv6.dat',)
+    '/usr/share/GeoIP/GeoIPv6.dat',
+)
 
 
 class LoginSessionsPanel(AdminPanel):
@@ -30,18 +30,20 @@ class LoginSessionsPanel(AdminPanel):
             except (pygeoip.GeoIPError, IOError):
                 pass
 
-        sessions = LoginSession.query.order_by(LoginSession.id.desc()).limit(
-            50).all()
-        unknown_country = _(u'Country unknown')
+        sessions = LoginSession.query \
+            .order_by(LoginSession.id.desc()) \
+            .limit(50) \
+            .all()
+        unknown_country = _('Country unknown')
 
-        for session in sessions:
+        def update_country(session):
             country = unknown_country
-
-            if geoips and session.ip_address:
+            if session.ip_address:
                 ip_address = session.ip_address
                 multiple = ip_address.split(',')
                 if multiple:
-                    # only use last ip in the list, most likely the public address
+                    # only use last ip in the list, most likely the public
+                    # address
                     ip_address = multiple[-1]
                 for g in geoips:
                     try:
@@ -54,6 +56,11 @@ class LoginSessionsPanel(AdminPanel):
                     else:
                         country = unknown_country
 
-                session.country = country
+                    session.country = country
 
-        return render_template("admin/login_sessions.html", **locals())
+        if geoips:
+            for session in sessions:
+                update_country(session)
+
+        ctx = {'sessions': sessions}
+        return render_template("admin/login_sessions.html", **ctx)
