@@ -1,30 +1,31 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
 from flask import render_template
 
 from abilian.i18n import _, _l
-from abilian.web.util import url_for
 from abilian.web.admin.panel import AdminPanel
+from abilian.web.util import url_for
 
 from . import views
 
 
 class UsersPanel(AdminPanel):
-    """
-    User administration panel.
-    """
+    """User administration panel."""
     id = 'users'
     label = _l(u'Users')
     icon = 'user'
 
     def install_additional_rules(self, add_url_rule):
         add_url_rule(
-            '/users', view_func=views.JsonUsersList.as_view('json_list'))
+            '/users',
+            view_func=views.JsonUsersList.as_view('json_list'),
+        )
         add_url_rule('/new', view_func=views.UserCreate.as_view('new'))
-        add_url_rule('/<int:user_id>', view_func=views.UserEdit.as_view('user'))
+        add_url_rule(
+            '/<int:user_id>',
+            view_func=views.UserEdit.as_view('user'))
 
     def get(self):
         # FIXME: use widgets.AjaxMainTableView instead
@@ -62,4 +63,7 @@ class UsersPanel(AdminPanel):
         }
 
         return render_template(
-            'admin/users.html', next=next, datatable_options=datatable_options)
+            'admin/users.html',
+            next=next,
+            datatable_options=datatable_options,
+        )
