@@ -6,7 +6,7 @@ from __future__ import absolute_import, division, print_function, \
 from functools import wraps
 
 from flask import Blueprint, current_app, jsonify, request
-from flask_wtf import Form
+from flask_wtf import Form as FlaskForm
 from werkzeug.exceptions import Forbidden
 
 blueprint = Blueprint('csrf', __name__, url_prefix='/csrf')
@@ -18,33 +18,33 @@ def json_token_view():
 
 
 def field():
+    """Return an instance of `wtforms.ext.csrf.fields.CSRFTokenField`, suitable
+    for rendering.
+
+    Renders an empty string if `config.CSRF_ENABLED` is not set.
     """
-    Return an instance of `wtforms.ext.csrf.fields.CSRFTokenField`, suitable for
-    rendering. Renders an empty string if `config.CSRF_ENABLED` is not set.
-    """
-    return Form().csrf_token
+    return FlaskForm().csrf_token
 
 
 def time_limit():
-    """Return current time limit for CSRF token.
-    """
+    """Return current time limit for CSRF token."""
     return current_app.config.get('WTF_CSRF_TIME_LIMIT', 3600)
 
 
 def name():
+    """Field name expected to have CSRF token.
+
+    Useful for passing it to JavaScript for instance.
     """
-    Field name expected to have CSRF token. Useful for passing it to
-    JavaScript for instance.
-    """
-    return u'csrf_token'
+    return 'csrf_token'
 
 
 def token():
+    """Value of current csrf token.
+
+    Useful for passing it to JavaScript for instance.
     """
-    Value of current csrf token. Useful for passing it to JavaScript for
-    instance.
-    """
-    return field().current_token or u''
+    return field().current_token or ''
 
 
 def support_graceful_failure(view):
@@ -70,7 +70,7 @@ def protect(view):
     @wraps(view)
     def csrf_check(*args, **kwargs):
         # an empty form is used to validate current csrf token and only that!
-        if not Form().validate():
+        if not FlaskForm().validate():
             raise Forbidden('CSRF validation failed.')
 
         return view(*args, **kwargs)
