@@ -1,24 +1,24 @@
 # coding=utf-8
-"""
-Extensions to WTForms fields, widgets and validators.
-"""
-from __future__ import absolute_import, print_function, division
+"""Extensions to WTForms fields, widgets and validators."""
+from __future__ import absolute_import, division, print_function
 
 import logging
-from functools import partial
 from collections import OrderedDict
+from functools import partial
 
-from wtforms.fields import HiddenField
-from wtforms.fields.core import Field
-from wtforms_alchemy import model_form_factory
-from flask import current_app, has_app_context, g
+from abilian.services import get_service
+from abilian.web.forms.widgets import DefaultViewWidget
+from flask import g, has_app_context
 from flask_login import current_user
-from flask_wtf.form import Form as BaseForm
+from flask_wtf import Form as BaseForm
+from six import string_types
+from wtforms.fields import HiddenField, Field
+from wtforms_alchemy import model_form_factory
 
-from abilian.i18n import _, _n
-from abilian.services.security import READ, WRITE, CREATE, Role, Anonymous
-from abilian.core.logging import patch_logger
 from abilian.core.entities import Entity
+from abilian.core.logging import patch_logger
+from abilian.i18n import _, _n
+from abilian.services.security import CREATE, READ, WRITE, Anonymous, Role
 
 from .fields import *  # noqa
 from .filters import *  # noqa
@@ -42,16 +42,17 @@ BabelTranslation = _BabelTranslation()
 
 
 class FormPermissions(object):
-    """Form role/permission manager.
-    """
+    """Form role/permission manager."""
 
-    def __init__(self,
-                 default=Anonymous,
-                 read=None,
-                 write=None,
-                 fields_read=None,
-                 fields_write=None,
-                 existing=None):
+    def __init__(
+            self,
+            default=Anonymous,
+            read=None,
+            write=None,
+            fields_read=None,
+            fields_write=None,
+            existing=None,
+    ):
         """
         :param default: default roles when not specified for field. Can be:
 
@@ -72,13 +73,15 @@ class FormPermissions(object):
         elif isinstance(default, dict):
             if 'default' not in default:
                 raise ValueError(
-                    '`default` parameter must have a "default" key')
+                    '`default` parameter must have a "default" key',
+                )
         elif callable(default):
             default = {'default': default}
         else:
             raise ValueError(
                 "No valid value for `default`. Use a Role, an iterable "
-                "of Roles, a callable, or a dict.")
+                "of Roles, a callable, or a dict.",
+            )
 
         self.default = default
         self.form = dict()
@@ -107,7 +110,8 @@ class FormPermissions(object):
         fields_defs = (
             (fields_read, READ),
             (fields_write, WRITE),
-            (fields_write, CREATE),)  # checking against CREATE permission
+            (fields_write, CREATE),
+        )  # checking against CREATE permission
         # at field level is the same as
         # WRITE permisssion
         for fields, permission in fields_defs:
@@ -115,14 +119,18 @@ class FormPermissions(object):
                 for field_name, allowed_roles in fields.items():
                     if isinstance(allowed_roles, Role):
                         allowed_roles = (allowed_roles,)
-                    self.fields.setdefault(field_name,
-                                           dict())[permission] = allowed_roles
+                    self.fields.setdefault(
+                        field_name,
+                        dict(),
+                    )[permission] = allowed_roles
 
-    def has_permission(self,
-                       permission,
-                       field=None,
-                       obj=None,
-                       user=current_user):
+    def has_permission(
+            self,
+            permission,
+            field=None,
+            obj=None,
+            user=current_user,
+    ):
         if obj is not None and not isinstance(obj, Entity):
             # permission/role can be set only on entities
             return True
@@ -158,17 +166,19 @@ class FormPermissions(object):
             else:
                 roles.extend(r)
 
-        svc = current_app.services['security']
-        return svc.has_role(user, role=roles, object=obj)
+        # TODO: replace w/: security = get_service('security')
+        # (Doing it now breaks a test)
+        # security = current_app.services['security']
+        security = get_service('security')
+        # security = get_service('security')
+        return security.has_role(user, role=roles, object=obj)
 
 
 class FormContext(object):
-    """
-    Allows :class:`forms <Form>` to set a context during instanciation, so that
-    subforms used in formfields / listformfields / etc can perform proper field
-    filtering according to original permission and user passed to top form
-    `__init__` method.
-    """
+    """Allows :class:`forms <Form>` to set a context during instanciation, so
+    that subforms used in formfields / listformfields / etc can perform proper
+    field filtering according to original permission and user passed to top
+    form `__init__` method."""
     permission = None
     user = None
 
@@ -251,14 +261,18 @@ class Form(BaseForm):
                     self._permissions.has_permission,
                     ctx.permission,
                     obj=ctx.obj,
-                    user=ctx.user)
+                    user=ctx.user,
+                )
                 empty_form = not has_permission()
 
                 for field_name in list(self._fields):
                     if empty_form or not has_permission(field=field_name):
                         logger.debug('{}(permission={!r}): field {!r}: removed'
-                                     ''.format(self.__class__.__name__,
-                                               ctx.permission, field_name))
+                                     ''.format(
+                                         self.__class__.__name__,
+                                         ctx.permission,
+                                         field_name,
+                                     ))
                         del self[field_name]
                         group = self._field_groups.get(field_name)
                         if group:
@@ -313,13 +327,16 @@ if not _PATCHED:
     del _core_field_init
 
     def _core_field_repr(self):
+        """`__repr__` that shows the name of the field instance.
+
+        Useful for tracing field errors (like in Sentry).
         """
-        `__repr__` that shows the name of the field instance. Useful for tracing field
-        errors (like in Sentry).
-        """
-        return '<{}.{} at 0x{:x} name={!r}>'.format(self.__class__.__module__,
-                                                    self.__class__.__name__,
-                                                    id(self), self.name)
+        return '<{}.{} at 0x{:x} name={!r}>'.format(
+            self.__class__.__module__,
+            self.__class__.__name__,
+            id(self),
+            self.name,
+        )
 
     patch_logger.info(Field.__module__ + '.Field.__repr__')
     Field.__repr__ = _core_field_repr
@@ -339,8 +356,7 @@ if not _PATCHED:
     del _core_field_render
 
     def render_view(self, **kwargs):
-        """Render data.
-        """
+        """Render data."""
         if 'widget_options' in kwargs and not kwargs['widget_options']:
             kwargs.pop('widget_options')
 
@@ -354,11 +370,9 @@ if not _PATCHED:
     del render_view
 
     def is_hidden(self):
-        """
-        WTForms is not consistent with hidden fields, since `flags.hidden` is not
-        set on `HiddenField` :-(
-        """
-        return (self.flags.hidden or isinstance(self, HiddenField))
+        """WTForms is not consistent with hidden fields, since `flags.hidden`
+        is not set on `HiddenField` :-("""
+        return self.flags.hidden or isinstance(self, HiddenField)
 
     patch_logger.info('Add method %s.Field.is_hidden' % Field.__module__)
     Field.is_hidden = property(is_hidden)
