@@ -18,7 +18,7 @@ from flask import Blueprint, current_app, g, jsonify, redirect, \
     render_template, request, session, url_for
 from flask_login import current_user
 from six import add_metaclass
-from sqlalchemy import func, orm
+from sqlalchemy import Date, DateTime, func, orm
 from sqlalchemy.sql.expression import asc, desc, nullsfirst, nullslast
 from werkzeug.exceptions import BadRequest
 
@@ -40,12 +40,6 @@ from .views import JSONView, JSONWhooshSearch, ObjectCreate, ObjectDelete, \
 
 logger = logging.getLogger(__name__)
 
-try:
-    # sqlalchemy 0.8
-    _DateAffinity = sa.types._DateAffinity
-except AttributeError:
-    _DateAffinity = sa.sql.sqltypes._DateAffinity
-
 
 class ModuleAction(Action):
     """Base action class for :class:`Module` actions.
@@ -124,7 +118,7 @@ def labelize(s):
 def make_single_view(form, **options):
     panels = []
     for gr in form._groups.items():
-        panel = Panel(gr[0], * [Row(x) for x in gr[1]])
+        panel = Panel(gr[0], *[Row(x) for x in gr[1]])
         panels.append(panel)
     return SingleView(form, *panels, **options)
 
@@ -223,8 +217,10 @@ EDIT_ACTION = Action(
     button='default',
     condition=lambda ctx: ctx['view'].can_edit,
     icon=FAIcon('edit'),
-    url=lambda ctx: url_for('.entity_edit',
-                            **{ctx['view'].pk: ctx['view'].obj.id}),
+    url=lambda ctx: url_for(
+        '.entity_edit',
+        **{ctx['view'].pk: ctx['view'].obj.id}
+    ),
 )
 
 DELETE_ACTION = Action(
@@ -407,7 +403,7 @@ class Module(object):
     components = ()  # type: Tuple
 
     # class based views. If not provided will be automaticaly created from
-    # EntityView etc defined above
+    # EntityView etc defined below
     base_template = 'base.html'
     view_cls = EntityView
     edit_cls = EntityEdit
@@ -522,10 +518,9 @@ class Module(object):
 
         # copy criterions instances; without that they may be shared by
         # subclasses
-        self.search_criterions = tuple((
-            copy.deepcopy(c)
-            for c in self.search_criterions
-        ))
+        self.search_criterions = copy.deepcopy(
+            self.__class__.search_criterions)
+
         for sc in self.search_criterions:
             sc.model = self.managed_class
 
@@ -712,39 +707,43 @@ class Module(object):
                         'sort_on',
                         default_sort_name,
                     )
-                sort_col = getattr(rel_model, rel_sort_name)
+                sort_col = getattr(rel_model, rel_sort_name, None)
 
             # XXX: Big hack, date are sorted in reverse order by default
-            if isinstance(sort_col, _DateAffinity):
+            if isinstance(sort_col, (Date, DateTime)):
                 sort_dir = 'asc' if sort_dir == 'desc' else 'desc'
+
             elif isinstance(sort_col, sa.types.String) or \
                     hasattr(sort_col, 'property') and \
                     isinstance(sort_col.property.columns[0].type, sa.types.String):
                 sort_col = func.lower(sort_col)
 
-            try:
-                direction = desc if sort_dir == 'desc' else asc
-                sort_col = direction(sort_col)
-            except BaseException:
-                # FIXME
-                pass
-
-            # sqlite does not support 'NULLS FIRST|LAST' in ORDER BY clauses
-            if engine.name != 'sqlite':
-                nullsorder = nullslast if sort_dir == 'desc' else nullsfirst
+            if sort_col is not None:
                 try:
-                    sort_col = nullsorder(sort_col)
+                    direction = desc if sort_dir == 'desc' else asc
+                    sort_col = direction(sort_col)
                 except BaseException:
                     # FIXME
                     pass
 
-            sort_cols.append(sort_col)
+                # sqlite does not support 'NULLS FIRST|LAST' in ORDER BY
+                # clauses
+                if engine.name != 'sqlite':
+                    nullsorder = nullslast if sort_dir == 'desc' else nullsfirst
+                    try:
+                        sort_col = nullsorder(sort_col)
+                    except BaseException:
+                        # FIXME
+                        pass
 
-        try:
-            query = query.order_by(*sort_cols)
-        except BaseException:
-            # FIXME
-            pass
+                sort_cols.append(sort_col)
+
+        if sort_cols:
+            try:
+                query = query.order_by(*sort_cols)
+            except BaseException:
+                # FIXME
+                pass
         query.reset_joinpoint()
         return query
 
