@@ -1,12 +1,9 @@
 # coding=utf-8
-"""
-Navigation elements.
+"""Navigation elements.
 
-Abilian define theses categories:
-  `section`:
-    Used for navigation elements relevant to site section
-  `user`:
-    User for element that should appear in user menu
+Abilian define theses categories:   `section`:     Used for navigation
+elements relevant to site section   `user`:     User for element that
+should appear in user menu
 """
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
@@ -19,9 +16,7 @@ from .action import ACTIVE, ENABLED, Action, Glyphicon, getset
 
 
 class NavItem(Action):
-    """
-    A single navigation item.
-    """
+    """A single navigation item."""
     divider = False
 
     def __init__(self, category, name, divider=False, *args, **kwargs):
@@ -47,9 +42,7 @@ class NavItem(Action):
 
 
 class NavGroup(NavItem):
-    """
-    A navigation group renders a list of items.
-    """
+    """A navigation group renders a list of items."""
     template_string = '''
     <ul class="nav navbar-nav {{ action.css_class }}">
       <li class="dropdown">
@@ -100,9 +93,7 @@ class NavGroup(NavItem):
 
 
 class BreadcrumbItem(object):
-    """
-    A breadcrumb element has at least a label or an icon.
-    """
+    """A breadcrumb element has at least a label or an icon."""
     #: Label shown to user. May be an i18n string instance
     label = None
 
@@ -112,13 +103,15 @@ class BreadcrumbItem(object):
     #: Additional text, can be used as tooltip for example
     description = None
 
-    #: either an unicode string or an :class:`Endpoint` instance.
+    #: either an Unicode string or an :class:`Endpoint` instance.
     _url = None
 
-    template_string = (u'{%- if url %}<a href="{{ url }}">{%- endif %}'
-                       u'{%- if item.icon %}{{ item.icon }} {%- endif %}'
-                       u'{{ item.label }}'
-                       u'{%- if url %}</a>{%- endif %}')
+    template_string = (
+        '{%- if url %}<a href="{{ url }}">{%- endif %}'
+        '{%- if item.icon %}{{ item.icon }} {%- endif %}'
+        '{{ item.label }}'
+        '{%- if url %}</a>{%- endif %}'
+    )
 
     def __init__(self, label='', url='#', icon=None, description=None):
         # don't test 'label or...': if label is a lazy_gettext, it will be
