@@ -1,9 +1,9 @@
 /* Abilian namespace */
-(function (factory) {
-  'use strict';
-  define('AbilianWidget', ['AbilianNS', 'jquery'], factory);
-}(function (Abilian, $) {
-  'use strict';
+(function(factory) {
+  "use strict";
+  define("AbilianWidget", ["AbilianNS", "jquery"], factory);
+})(function(Abilian, $) {
+  "use strict";
 
   /**
    * Initialize application parameters. Must be called when all resources are
@@ -15,21 +15,21 @@
    * @param createFun: function(*params). Within function 'this' is set as
    * the item to widgetize wrapped with jQuery.
    */
-  Abilian.registerWidgetCreator = function (name, createFun) {
+  Abilian.registerWidgetCreator = function(name, createFun) {
     widgetsCreators[name] = createFun;
   };
 
-  Abilian.getWidgetCreator = function (name) {
+  Abilian.getWidgetCreator = function(name) {
     return widgetsCreators[name];
   };
 
   /*
    * Initialiaze a single element.
    */
-  Abilian.initJsWidget = function () {
+  Abilian.initJsWidget = function() {
     var $this = $(this);
-    var creatorName = $this.data('init-with');
-    var params = $this.data('init-params');
+    var creatorName = $this.data("init-with");
+    var params = $this.data("init-params");
     var creatorFunc = widgetsCreators[creatorName];
 
     if (creatorFunc === undefined) {
@@ -46,7 +46,7 @@
   /*
    * Custom events
    */
-  Abilian.events.widgetsInitialized = 'widgets-initiliazed';
+  Abilian.events.widgetsInitialized = "widgets-initiliazed";
 
   return Abilian;
-}));
+});
