@@ -1,10 +1,9 @@
 # coding=utf-8
-"""
-"""
-from __future__ import absolute_import, print_function, division
+""""""
+from __future__ import absolute_import, division, print_function
 
-from .extension import TagsExtension
 from .criterion import TagCriterion
+from .extension import TagsExtension
 
 __all__ = ['TagsExtension', 'TagCriterion']
 
