@@ -1,9 +1,10 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
+import six
+
 from abilian.core.models.tag import TAGS_ATTR, Tag, is_support_tagging
 from abilian.i18n import _l
 from abilian.web import url_for
@@ -18,9 +19,8 @@ ENTITY_DEFAULT_NS_ATTR = '__tags_default_ns__'
 
 
 def ns(ns):
-    """
-    Class decorator that sets default tags namespace to use with its instances.
-    """
+    """Class decorator that sets default tags namespace to use with its
+    instances."""
 
     def setup_ns(cls):
         setattr(cls, ENTITY_DEFAULT_NS_ATTR, ns)
@@ -30,8 +30,7 @@ def ns(ns):
 
 
 class _TagsForm(Form):
-    """
-    Form to workaround a wtforms limitation: fields cannot start with an
+    """Form to workaround a wtforms limitation: fields cannot start with an
     underscore, so '__tags__' is not accepted.
 
     This form help process tags (and only tags).
@@ -45,12 +44,12 @@ class _TagsForm(Form):
             tags = getattr(obj, TAGS_ATTR, set())
 
         super(_TagsForm, self).process(
-            formdata=formdata, obj=None, data=data, tags=tags, **kwargs)
+            formdata=formdata, obj=None, data=data, tags=tags, **kwargs
+        )
 
 
 class TagsExtension(object):
-    """
-    API for tags, installed as an application extension.
+    """API for tags, installed as an application extension.
 
     It is also available in templates as `tags`.
     """
@@ -92,23 +91,23 @@ class TagsExtension(object):
         return getattr(entity, ENTITY_DEFAULT_NS_ATTR, 'default')
 
     def entity_tags_form(self, entity, ns=None):
-        """
-        Construct a form class with a field for tags in namespace `ns`.
-        """
+        """Construct a form class with a field for tags in namespace `ns`."""
         if ns is None:
             ns = self.entity_default_ns(entity)
 
-        field = TagsField(label=_l(u'Tags'), ns=ns)
-        cls = type(b'EntityNSTagsForm', (_TagsForm,), {'tags': field})
+        field = TagsField(label=_l('Tags'), ns=ns)
+        if six.PY2:
+            cls = type(b'EntityNSTagsForm', (_TagsForm,), {b'tags': field})
+        else:
+            cls = type('EntityNSTagsForm', (_TagsForm,), {'tags': field})
         return cls
 
     def get(self, ns, label=None):
-        """
-        Return :class:`tags instances<~Tag>` for the namespace `ns`, ordered by
-        label.
+        """Return :class:`tags instances<~Tag>` for the namespace `ns`, ordered
+        by label.
 
-        If `label` is not None the only one instance may be returned, or `None` if
-        no tags exists for this label.
+        If `label` is not None the only one instance may be returned, or
+        `None` if no tags exists for this label.
         """
         query = Tag.query.filter(Tag.ns == ns)
 
@@ -143,12 +142,12 @@ class TagsExtension(object):
             pass
 
     def get_form_context(self, obj, ns=None):
-        """
-        Return a dict: form instance, action button, submit url...
+        """Return a dict: form instance, action button, submit url...
+
         Used by macro m_tags_form(entity)
         """
-        ctx = {}
-        ctx['url'] = url_for('entity_tags.edit', object_id=obj.id)
-        ctx['form'] = self.entity_tags_form(obj)(obj=obj, ns=ns)
-        ctx['buttons'] = [EDIT_BUTTON]
-        return ctx
+        return {
+            'url': url_for('entity_tags.edit', object_id=obj.id),
+            'form': self.entity_tags_form(obj)(obj=obj, ns=ns),
+            'buttons': [EDIT_BUTTON],
+        }
