@@ -1,6 +1,5 @@
 # coding=utf-8
-"""
-"""
+""""""
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
 
@@ -18,13 +17,15 @@ from abilian.web.views import BaseObjectView, JSONView, ObjectCreate, \
 from .forms import TagForm
 
 bp = Blueprint(
-    'tags', __name__, url_prefix='/tags', template_folder='templates')
+    'tags',
+    __name__,
+    url_prefix='/tags',
+    template_folder='templates',
+)
 
 
 class BaseTagView(object):
-    """
-    Mixin for tag views
-    """
+    """Mixin for tag views."""
     Model = Tag
     Form = TagForm
 
@@ -37,7 +38,7 @@ class BaseTagView(object):
 
 
 class TagEdit(BaseTagView, ObjectEdit):
-    _message_success = _l(u'Tag edited')
+    _message_success = _l('Tag edited')
 
 
 edit_view = TagEdit.as_view('edit')
@@ -45,7 +46,7 @@ bp.route('/manage/<int:object_id>/edit')(edit_view)
 
 
 class TagCreate(BaseTagView, ObjectCreate):
-    _message_success = _l(u'Tag created')
+    _message_success = _l('Tag created')
 
 
 create_view = TagCreate.as_view('create')
@@ -53,7 +54,7 @@ bp.route('/manage/new')(create_view)
 
 
 class TagDelete(BaseTagView, ObjectDelete):
-    _message_success = _l(u'Tag deleted')
+    _message_success = _l('Tag deleted')
 
 
 delete_view = TagDelete.as_view('delete')
@@ -108,17 +109,25 @@ class EntityTagManage(BaseEntityTagView, ObjectEdit):
         assert mode in ('add', 'remove')
         self.mode = mode
 
-    def form_valid(self):
+    def form_valid(self, redirect_to=None):
         ns = self.form.ns.data
         label = self.form.label.data
         op = getattr(self.extension, self.mode)
         op(self.entity, ns=ns, label=label)
 
 
-entity_bp.route('/<int:object_id>/add')(EntityTagManage.as_view(
-    'add', mode='add'))
-entity_bp.route('/<int:object_id>/remove')(EntityTagManage.as_view(
-    'remove', mode='remove'))
+entity_bp.route('/<int:object_id>/add')(
+    EntityTagManage.as_view(
+        'add',
+        mode='add',
+    ),
+)
+entity_bp.route('/<int:object_id>/remove')(
+    EntityTagManage.as_view(
+        'remove',
+        mode='remove',
+    ),
+)
 
 
 class EntityTagEdit(ObjectEdit):
