@@ -10,7 +10,12 @@ from abilian.testing import BaseTestCase
 from abilian.web.action import Action, Glyphicon, StaticIcon, actions
 
 BASIC = Action(
-    'cat_1', 'basic', 'Basic Action', url='http://some.where', icon='ok')
+    'cat_1',
+    'basic',
+    'Basic Action',
+    url='http://some.where',
+    icon='ok',
+)
 CONDITIONAL = Action(
     'cat_1',
     'conditional',
@@ -18,23 +23,23 @@ CONDITIONAL = Action(
     url='http://condition.al',
     condition=lambda ctx: ctx['show_all'],
     icon=Glyphicon('hand-right'),
-    button='warning')
+    button='warning',
+)
 
 OTHER_CAT = Action(
     'cat_2:sub',
     'other',
     'Other Action',
     url=lambda ctx: 'http://count?%d' % len(ctx),
-    icon=StaticIcon(
-        'icons/other.png', size=14),
-    css='custom-class')
+    icon=StaticIcon('icons/other.png', size=14),
+    css='custom-class',
+)
 
 ALL_ACTIONS = (BASIC, CONDITIONAL, OTHER_CAT)
 
 
 class TestActions(BaseTestCase):
-    """Test Action and ActionRegistry.
-    """
+    """Test Action and ActionRegistry."""
 
     def setUp(self):
         BaseTestCase.setUp(self)
@@ -69,11 +74,11 @@ class TestActions(BaseTestCase):
         assert actions.for_category('cat_1') == [BASIC]
 
     def test_enabled(self):
-        assert CONDITIONAL.enabled == True
+        assert CONDITIONAL.enabled
         assert actions.for_category('cat_1') == [BASIC, CONDITIONAL]
 
         CONDITIONAL.enabled = False
-        assert CONDITIONAL.enabled == False
+        assert not CONDITIONAL.enabled
         assert actions.for_category('cat_1') == [BASIC]
 
     def test_action_url_from_context(self):
@@ -82,19 +87,22 @@ class TestActions(BaseTestCase):
         assert OTHER_CAT.url({}) == 'http://count?0'
 
     def test_render(self):
-        assert (BASIC.render() == Markup(
+        assert BASIC.render() == Markup(
             '<a class="action action-cat_1 action-cat_1-basic" '
             'href="http://some.where">'
-            '<i class="glyphicon glyphicon-ok"></i> Basic Action</a>'))
+            '<i class="glyphicon glyphicon-ok"></i> Basic Action</a>',
+        )
 
-        assert (CONDITIONAL.render() == Markup(
+        assert CONDITIONAL.render() == Markup(
             '<a class="action action-cat_1 action-cat_1-conditional '
             'btn btn-warning" href="http://condition.al">'
             '<i class="glyphicon glyphicon-hand-right"></i> '
-            'Conditional Action</a>'))
+            'Conditional Action</a>',
+        )
 
-        assert (OTHER_CAT.render() == Markup(
+        assert OTHER_CAT.render() == Markup(
             '<a class="action action-cat_2-sub action-cat_2-sub-other '
             'custom-class" href="http://count?3">'
             '<img src="/static/icons/other.png" width="14" height="14" /> '
-            'Other Action</a>'))
+            'Other Action</a>',
+        )
