@@ -1,8 +1,8 @@
-"""
-A few utility functions.
+# coding=utf-8
+"""A few utility functions.
 
-See https://docs.djangoproject.com/en/dev/topics/http/shortcuts/ for more ideas
-of stuff to implement.
+See https://docs.djangoproject.com/en/dev/topics/http/shortcuts/ for
+more ideas of stuff to implement.
 """
 from __future__ import absolute_import, division, print_function, \
     unicode_literals
@@ -25,8 +25,8 @@ except ImportError:
 def url_for(obj, **kw):
     """Polymorphic variant of Flask's `url_for` function.
 
-    Behaves like the original function when the first argument is a string.
-    When it's an object, it
+    Behaves like the original function when the first argument is a
+    string. When it's an object, it
     """
     if isinstance(obj, string_types):
         return flask_url_for(obj, **kw)
@@ -43,14 +43,13 @@ def url_for(obj, **kw):
 
 
 def get_object_or_404(cls, *args):
-    """Shorthand similar to Django's `get_object_or_404`.
-    """
+    """Shorthand similar to Django's `get_object_or_404`."""
 
     return cls.query.filter(*args).first_or_404()
 
 
 def send_file_from_directory(filename, directory, app=None):
-    """Helper to add static rules, like in `abilian.app`.app
+    """Helper to add static rules, like in `abilian.app`.app.
 
     Example use::
 
@@ -63,7 +62,8 @@ def send_file_from_directory(filename, directory, app=None):
     if app is None:
         app = current_app
     cache_timeout = app.get_send_file_max_age(filename)
-    return send_from_directory(directory, filename, cache_timeout=cache_timeout)
+    return send_from_directory(
+        directory, filename, cache_timeout=cache_timeout)
 
 
 def capture_stream_errors(logger, msg):
@@ -85,7 +85,8 @@ def capture_stream_errors(logger, msg):
             # this is for developpers convenience. The debugger middleware doesn't
             # work when using streamed responses.
             should_pdb = current_app.debug and session.get(
-                'pdb_streamed_responses')
+                'pdb_streamed_responses',
+            )
             try:
                 generator = fun(*args, **kwargs)
                 for chunk in generator:
@@ -97,7 +98,8 @@ def capture_stream_errors(logger, msg):
                 type_, value, tb = sys.exc_info()
                 if tb.tb_next is not None:
                     # error has happened inside decorated function, remove us from top
-                    # stack: better readability in logs, accurate label in sentry
+                    # stack: better readability in logs, accurate label in
+                    # sentry
                     tb = tb.tb_next
 
                 logger.error(msg, exc_info=(type_, value, tb))
